@@ -1,6 +1,6 @@
 package SPOPS;
 
-# $Id: SPOPS.pm,v 3.2 2002/09/09 12:41:23 lachoy Exp $
+# $Id: SPOPS.pm,v 3.3 2002/09/14 23:19:09 lachoy Exp $
 
 use strict;
 use base  qw( Exporter ); # Class::Observable
@@ -11,8 +11,8 @@ use SPOPS::Tie      qw( IDX_CHANGE IDX_SAVE IDX_CHECK_FIELDS IDX_LAZY_LOADED );
 use SPOPS::Secure   qw( SEC_LEVEL_WRITE );
 
 $SPOPS::AUTOLOAD  = '';
-$SPOPS::VERSION   = '0.69';
-$SPOPS::Revision  = sprintf("%d.%02d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::VERSION   = '0.70';
+$SPOPS::Revision  = sprintf("%d.%02d", q$Revision: 3.3 $ =~ /(\d+)\.(\d+)/);
 
 # Note that switching on DEBUG will generate LOTS of messages, since
 # many SPOPS classes import this constant
@@ -497,7 +497,7 @@ sub as_html {
 
 sub check_security          { return SEC_LEVEL_WRITE }
 sub check_action_security   { return SEC_LEVEL_WRITE }
-sub create_initial_security { return 1               }
+sub create_initial_security { return 1 }
 
 
 ########################################
@@ -582,7 +582,7 @@ sub set { return $_[0]->{ $_[1] } = $_[2] }
 
 sub as_data_only {
     my ( $self ) = @_;
-    return { map { $_ => $self->{ $_ } } keys %{ $self } };
+    return { map { $_ => $self->{ $_ } } grep ! /^(tmp|_)/, keys %{ $self } };
 }
 
 # Backward compatible...
